==> jbpm-bpmn-4.3-sources.jar: org/jbpm/bpmn/flownodes/ScriptTaskBinding.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.bpmn.flownodes;

import org.jbpm.pvm.internal.util.XmlUtil;
import org.jbpm.pvm.internal.xml.Parse;
import org.jbpm.pvm.internal.xml.Parser;
import org.w3c.dom.Element;


public class ScriptTaskBinding extends BpmnBinding {

  
  public ScriptTaskBinding() {
    super("scriptTask");
  }

  public Object parse(Element element, Parse parse, Parser parser) {

    String scriptLanguage = XmlUtil.attribute(element, "scriptLanguage"); 
    String script = XmlUtil.element(element, "script").getTextContent();

    ScriptTaskActivity scriptTaskActivity = new ScriptTaskActivity();
    scriptTaskActivity.setLanguage(scriptLanguage);
    scriptTaskActivity.setScript(script);

    return scriptTaskActivity;
  }
}

==> jbpm-bpmn-4.4-sources.jar: org/jbpm/bpmn/flownodes/ScriptTaskBinding.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.bpmn.flownodes;

import org.jbpm.bpmn.parser.BpmnParser;
import org.jbpm.pvm.internal.util.XmlUtil;
import org.jbpm.pvm.internal.xml.Parse;
import org.w3c.dom.Element;


public class ScriptTaskBinding extends BpmnBinding {

  
  public ScriptTaskBinding() {
    super("scriptTask");
  }
  
  public Object parse(Element element, Parse parse, BpmnParser bpmnParser) {
    String scriptLanguage = XmlUtil.attribute(element, "scriptLanguage"); 
    String script = XmlUtil.element(element, "script").getTextContent();

    ScriptTaskActivity scriptTaskActivity = new ScriptTaskActivity();
    scriptTaskActivity.setLanguage(scriptLanguage);
    scriptTaskActivity.setScript(script);
    scriptTaskActivity.setDefault(getDefault());

    return scriptTaskActivity;
  }

}
